@@ -5,7 +5,7 @@ from __future__ import with_statement
 Author: Jonas Wagner
 
 Play it slowly
-Copyright (C) 2009 - 2010 Jonas Wagner
+Copyright (C) 2009 - 2011 Jonas Wagner
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ import gst # this has to be after the Pipeline
 _ = lambda s: s # may be add gettext later
 
 NAME = u"Play it slowly"
-VERSION = "1.3"
+VERSION = "1.4.0"
 WEBSITE = "http://29a.ch/playitslowly/"
 
 if sys.platform == "win32":
@@ -102,6 +102,8 @@ class MainWindow(gtk.Window):
         self.set_border_width(5)
 
         self.vbox = gtk.VBox()
+        self.accel_group = gtk.AccelGroup()
+        self.add_accel_group(self.accel_group)
 
         self.pipeline = Pipeline(sink)
 
@@ -114,37 +116,40 @@ class MainWindow(gtk.Window):
         self.recentbutton.connect("clicked", self.show_recent)
         filechooserhbox.pack_end(self.recentbutton, False, False)
 
-        self.speedchooser = mygtk.TextScale(gtk.Adjustment(1.00, 0.10, 4.0, 0.05, 0.05))
+        self.speedchooser = mygtk.TextScaleReset(gtk.Adjustment(1.00, 0.10, 4.0, 0.05, 0.05))
         self.speedchooser.scale.connect("value-changed", self.speedchanged)
         self.speedchooser.scale.connect("button-press-event", self.speedpress)
         self.speedchooser.scale.connect("button-release-event", self.speedrelease)
         self.speedchangeing = False
 
-        self.pitchchooser = mygtk.TextScale(gtk.Adjustment(0.0, -24.0, 24.0, 1.0, 1.0, 1.0))
+        self.pitchchooser = mygtk.TextScaleReset(gtk.Adjustment(0.0, -24.0, 24.0, 1.0, 1.0, 1.0))
         self.pitchchooser.scale.connect("value-changed", self.pitchchanged)
 
-        self.pitchchooser_fine = mygtk.TextScale(gtk.Adjustment(0.0, -50, 50, 1.0, 1.0, 1.0))
+        self.pitchchooser_fine = mygtk.TextScaleReset(gtk.Adjustment(0.0, -50, 50, 1.0, 1.0, 1.0))
         self.pitchchooser_fine.scale.connect("value-changed", self.pitchchanged)
 
-        self.positionchooser = mygtk.TextScale(gtk.Adjustment(0.0, 0.0, 100.0))
+        self.positionchooser = mygtk.ClockScale(gtk.Adjustment(0.0, 0.0, 100.0))
         self.positionchooser.scale.connect("button-press-event", self.start_seeking)
         self.positionchooser.scale.connect("button-release-event", self.positionchanged)
         self.seeking = False
 
-        self.startchooser = mygtk.TextScale(gtk.Adjustment(0.0, 0, 100.0))
+        self.startchooser = mygtk.TextScaleWithCurPos(self.positionchooser, gtk.Adjustment(0.0, 0, 100.0))
         self.startchooser.scale.connect("button-press-event", self.start_seeking)
         self.startchooser.scale.connect("button-release-event", self.seeked)
+        self.startchooser.add_accelerator("clicked", self.accel_group, ord('['), gtk.gdk.CONTROL_MASK, ())
+        self.startchooser.add_accelerator("clicked", self.accel_group, ord('['), 0, ())
 
-        self.endchooser = mygtk.TextScale(gtk.Adjustment(1.0, 0, 100.0, 0.01, 0.01))
+        self.endchooser = mygtk.TextScaleWithCurPos(self.positionchooser, gtk.Adjustment(1.0, 0, 100.0, 0.01, 0.01))
         self.endchooser.scale.connect("button-press-event", self.start_seeking)
         self.endchooser.scale.connect("button-release-event", self.seeked)
+        self.endchooser.add_accelerator("clicked", self.accel_group, ord(']'), gtk.gdk.CONTROL_MASK, ())
+        self.endchooser.add_accelerator("clicked", self.accel_group, ord(']'), 0, ())
 
-        self.vbox.pack_start(mygtk.form([
-            (_(u"Audio File"), filechooserhbox),
-            (_(u"Speed (times)"), self.speedchooser),
+        self.vbox.pack_start(filechooserhbox)
+        self.vbox.pack_start(self.positionchooser)
+        self.vbox.pack_start(mygtk.form([(_(u"Speed (times)"), self.speedchooser),
             (_(u"Pitch (semitones)"), self.pitchchooser),
             (_(u"Fine Pitch (cents)"), self.pitchchooser_fine),
-            (_(u"Position (seconds)"), self.positionchooser),
             (_(u"Start Position (seconds)"), self.startchooser),
             (_(u"End Position (seconds)"), self.endchooser)
         ]), False, False)
@@ -157,6 +162,8 @@ class MainWindow(gtk.Window):
         self.play_button.set_use_stock(True)
         self.play_button.set_sensitive(False)
         buttonbox.pack_start(self.play_button)
+        # make SPACE a shortcut for play/pause (CTRL-SPC would be better?)
+        self.play_button.add_accelerator("clicked", self.accel_group, ord(' '), 0, ())
 
         self.back_button = gtk.Button(gtk.STOCK_MEDIA_REWIND)
         self.back_button.connect("clicked", self.back)
@@ -206,13 +213,14 @@ class MainWindow(gtk.Window):
 
     def add_recent(self, uri):
         manager = gtk.recent_manager_get_default()
-        mime_type = mimetypes.guess_type(uri)[0]
         app_exec = "playitslowly \"%s\"" % uri
-        manager.add_full(uri, {
-            "app_name": "playitslowly",
-            "app_exec": "playitslowly",
-            "mime_type": mime_type
-        })
+        mime_type = mimetypes.guess_type(uri)[0]
+        if mime_type:
+            manager.add_full(uri, {
+                "app_name": "playitslowly",
+                "app_exec": "playitslowly",
+                "mime_type": mime_type
+            })
 
 
     def show_recent(self, sender=None):
@@ -431,13 +439,13 @@ class MainWindow(gtk.Window):
         about.set_logo(mygtk.iconfactory.get_icon("playitslowly", 128))
         about.set_name(NAME)
         about.set_version(VERSION)
-        about.set_authors(["Jonas Wagner"])
+        about.set_authors(["Jonas Wagner", "Elias Dorneles"])
         about.set_translator_credits(_("translator-credits"))
-        about.set_copyright("Copyright (c) 2009 - 2010 Jonas Wagner")
+        about.set_copyright("Copyright (c) 2009 - 2011 Jonas Wagner")
         about.set_website(WEBSITE)
         about.set_website_label(WEBSITE)
         about.set_license("""
-Copyright (C) 2009 - 2010 Jonas Wagner
+Copyright (C) 2009 - 2011 Jonas Wagner
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
